package SHARYANTO::Roles;

use 5.010001;

our $VERSION = '0.66'; # VERSION

1;
# ABSTRACT: SHARYANTO's temporary namespace for various roles

__END__

=pod

=encoding UTF-8

=head1 NAME

SHARYANTO::Roles - SHARYANTO's temporary namespace for various roles

=head1 VERSION

version 0.66

=head1 DESCRIPTION

=head1 FUNCTIONS


None are exported by default, but they are exportable.

=head1 FAQ

=head2 What is this?

This distribution is a heterogenous collection of roles currently used in my
modules and applications. The roles will eventually have their own proper names
and distributions, if they prove to be worth it.

See L<SHARYANTO> about this temporary namespace.

=head1 SEE ALSO

L<SHARYANTO>

L<SHARYANTO::Utils>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/SHARYANTO-Roles>.

=head1 SOURCE

Source repository is at L<https://github.com/sharyanto/perl-SHARYANTO-Roles>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
L<https://rt.cpan.org/Public/Dist/Display.html?Name=SHARYANTO-Roles>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
